@@ -23,7 +23,7 @@ class MetaStoreInitializer(object):
     Create a new initializer
     Param user The user login for the git repo
     """
-    def __init__(self):
+    def __init__(self, system):
         self.template_dir = None
         self.template_repo = None
 
