@@ -16,6 +16,7 @@
 import copy
 import ferry.install
 from ferry.install import Installer
+from ferry.config.system.info import System
 from heatclient import client as heat_client
 from heatclient.exc import HTTPUnauthorized, HTTPNotFound, HTTPBadRequest
 import json
@@ -25,7 +26,6 @@ from neutronclient.neutron import client as neutron_client
 from novaclient import client as nova_client
 import os
 from pymongo import MongoClient
-import re
 import sys
 import time
 import uuid
@@ -40,19 +40,28 @@ class SingleLauncher(object):
     environments that only support a single network (i.e., HP Cloud). 
     """
     def __init__(self, controller):
+        self.name = "OpenStack launcher"
         self.docker_registry = None
         self.docker_user = None
         self.heat_server = None
         self.openstack_key = None
 
+        self.system = System()
         self.installer = Installer()
         self.controller = controller
         self._init_open_stack()
         self._init_app_db()
 
+    def support_proxy(self):
+        """
+        The OpenStack backend supports proxy mode by assigning all the
+        machines a floating IP.
+        """
+        return True
+
     def _init_app_db(self):
         self.mongo = MongoClient(os.environ['MONGODB'], 27017, connectTimeoutMS=6000)
-        self.apps = self.mongo['openstack']['heat']
+        self.apps = self.mongo['cloud']['openstack']
 
     def _init_open_stack(self):
         conf = ferry.install.read_ferry_config()
@@ -121,6 +130,7 @@ class SingleLauncher(object):
         # cidr, gateway, etc.)
         self._init_openstack_clients()
         self._collect_subnet_info()
+
     def _get_host_key(self):
         """
         Get the location of the private ssh key. 
@@ -683,14 +693,14 @@ class SingleLauncher(object):
                         sec_group_ports.append( (s[0], s[0]) )
         else:
             if proxy:
+                # Otherwise, the backend should also get floating IPs
+                # so that the controller can access it. 
+                floating_ip = True
+            else:
                 # If the controller is acting as a proxy, then it has
                 # direct access to the VMs, so the backend shouldn't
                 # get any floating IPs. 
                 floating_ip = False
-            else:
-                # Otherwise, the backend should also get floating IPs
-                # so that the controller can access it. 
-                floating_ip = True
 
             # We need to create a range tuple, so check if 
             # the exposed port is a range.
